pub struct TestCaseFixtureProperties(/* private fields */);Implementations
Sourceimpl TestCaseFixtureProperties
impl TestCaseFixtureProperties
pub const NEEDS_SAME_CWD: Self
pub const NOT_IN_DEFAULT_SET: Self
pub const MATCHES_CDYLIB: Self
pub const MATCHES_TEST_MULTIPLY_TWO: Self
pub const NOT_IN_DEFAULT_SET_UNIX: Self
pub const IS_BENCHMARK: Self
Sourcepub const BENCH_OVERRIDE_TIMEOUT: Self
pub const BENCH_OVERRIDE_TIMEOUT: Self
Benchmark that times out with the with-bench-override profile.
Sourcepub const BENCH_TERMINATION: Self
pub const BENCH_TERMINATION: Self
Benchmark that times out with the with-bench-termination profile.
Sourcepub const BENCH_IGNORES_TEST_TIMEOUT: Self
pub const BENCH_IGNORES_TEST_TIMEOUT: Self
Benchmark that passes with the with-test-termination-only profile.
Sourcepub const SLOW_TIMEOUT_SUBSTRING: Self
pub const SLOW_TIMEOUT_SUBSTRING: Self
Test with “slow_timeout” as a substring.
Sourcepub const TEST_SLOW_TIMEOUT_SUBSTRING: Self
pub const TEST_SLOW_TIMEOUT_SUBSTRING: Self
Test with “test_slow_timeout” as a substring.
Sourcepub const FLAKY_SLOW_TIMEOUT_SUBSTRING: Self
pub const FLAKY_SLOW_TIMEOUT_SUBSTRING: Self
Test with “flaky_slow_timeout” as a substring.
Sourcepub const EXACT_TEST_SLOW_TIMEOUT: Self
pub const EXACT_TEST_SLOW_TIMEOUT: Self
Exactly test_slow_timeout (not test_slow_timeout_2 or test_slow_timeout_subprocess).
Sourcepub const FLAKY_RESULT_FAIL: Self
pub const FLAKY_RESULT_FAIL: Self
Flaky test configured with flaky-result = "fail".
Sourcepub const FLAKY_RESULT_FAIL_JUNIT_SUCCESS: Self
pub const FLAKY_RESULT_FAIL_JUNIT_SUCCESS: Self
Flaky test configured with flaky-result = "fail" and
junit.flaky-fail-status = "success".
Sourceimpl TestCaseFixtureProperties
impl TestCaseFixtureProperties
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl TestCaseFixtureProperties
impl TestCaseFixtureProperties
Sourcepub const fn iter(&self) -> Iter<TestCaseFixtureProperties>
pub const fn iter(&self) -> Iter<TestCaseFixtureProperties>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TestCaseFixtureProperties>
pub const fn iter_names(&self) -> IterNames<TestCaseFixtureProperties>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.